# Version: 1.3.1 (17-03-2022)

* [#21](https://github.com/GispoCoding/pytest-qgis/pull/21): Add a newProjectCreated signal to QgisInterface mock class


# Version: 1.3.0 (18-01-2022)

* [#17](https://github.com/GispoCoding/pytest-qgis/pull/17): Add QgisBot to make it easier to access utility functions
* [#14](https://github.com/GispoCoding/pytest-qgis/pull/14): Use QMainWindow with parent and store toolbars with iface.addToolBar

# Version: 1.2.0 (17-01-2022)

* [#10](https://github.com/GispoCoding/pytest-qgis/pull/10): Allow showing attribute dialog
* [#9](https://github.com/GispoCoding/pytest-qgis/pull/9): Use QgsLayerTreeMapCanvasBridge to keep the layer order correct


# Version: 1.1.2 (12-16-2021)

* [#8](https://github.com/GispoCoding/pytest-qgis/pull/8): Add stub iface.activeLayer logic

# Version: 1.1.1 (12-07-2021)

* Reduce test time by getting basemap only when needed

# Version: 1.1.0 (11-25-2021)

* [#5](https://github.com/GispoCoding/pytest-qgis/pull/5): Add configurable options
* [#5](https://github.com/GispoCoding/pytest-qgis/pull/5): Add clean_qgis_layer decorator
* [#5](https://github.com/GispoCoding/pytest-qgis/pull/5): Deprecate new_project in favour of qgis_new_project
* [#5](https://github.com/GispoCoding/pytest-qgis/pull/5): Add qgis_show_map marker and functionality

# Version: 1.0.3 (11-22-2021)

* [#4](https://github.com/GispoCoding/pytest-qgis/pull/4): Use hook to patch the imported iface

# Version: 1.0.2 (10-08-2021)

* Check if canvas is deleted before setting layers

# Version: 1.0.1 (10-07-2021)

* Include py.typed

# Version: 1.0.0 (10-07-2021)

* [#1](https://github.com/GispoCoding/pytest-qgis/pull/1) Add processing framework initialization fixture and test
* [#3](https://github.com/GispoCoding/pytest-qgis/pull/3): Add type hints
* [#10](https://github.com/GispoCoding/pytest-qgis/pull/2): Use empty configuration path in tests

# Version: 0.1.0

* Initial plugin
